==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="39"/>
        <source>Print playback status</source>
        <translation>Wiedergabestatus ausgeben</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="41"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Namen des Titels formatiert ausgeben (Beispiel: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="42"/>
        <source>Print --nowplaying syntax</source>
        <translation>Syntax von --nowplaying ausgeben</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="88"/>
        <source>Syntax:</source>
        <translation>Syntax:</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="89"/>
        <source>%p - artist</source>
        <translation>%p – Interpret</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="90"/>
        <source>%a - album</source>
        <translation>%a – Album</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="91"/>
        <source>%aa - album artist</source>
        <translation>%aa - Albuminterpret</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="92"/>
        <source>%t - title</source>
        <translation>%t – Titel</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="93"/>
        <source>%n - track</source>
        <translation>%n – Titel</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN – 2-stellige Titelnummer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%g - genre</source>
        <translation>%g – Genre</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%c - comment</source>
        <translation>%c – Kommentar</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%C - composer</source>
        <translation>%C – Komponist</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%D - disc number</source>
        <translation>%D – CD-Nummer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%f - file name</source>
        <translation>%f – Dateiname</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%F - full path</source>
        <translation>%F – Vollständiger Pfad</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%y - year</source>
        <translation>%y – Jahr</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%l - duration</source>
        <translation>%l – Abspieldauer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) – Bedingung</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="39"/>
        <source>Print playback status</source>
        <translation>Wiedergabestatus ausgeben</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="41"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Namen des Titels formatiert ausgeben (Beispiel: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="42"/>
        <source>Print --nowplaying syntax</source>
        <translation>Syntax von --nowplaying ausgeben</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="87"/>
        <source>Syntax:</source>
        <translation>Syntax:</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="88"/>
        <source>%p - artist</source>
        <translation>%p – Interpret</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="89"/>
        <source>%a - album</source>
        <translation>%a – Album</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="90"/>
        <source>%aa - album artist</source>
        <translation>%aa - Albuminterpret</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="91"/>
        <source>%t - title</source>
        <translation>%t – Titel</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="92"/>
        <source>%n - track</source>
        <translation>%n – Titel</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="93"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN – 2-stellige Titelnummer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>%g - genre</source>
        <translation>%g – Genre</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%c - comment</source>
        <translation>%c – Kommentar</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%C - composer</source>
        <translation>%C – Komponist</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%D - disc number</source>
        <translation>%D – CD-Nummer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%f - file name</source>
        <translation>%f – Dateiname</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%F - full path</source>
        <translation>%F – Vollständiger Pfad</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%y - year</source>
        <translation>%y – Jahr</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%l - duration</source>
        <translation>%l – Abspieldauer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) – Bedingung</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation>%dir(n) - Verzeichnisname auf n Ebenen darüber</translation>
    </message>
</context>
</TS>
